Each entry is itself a named list with year_or_range,
kind, csv_filename, sidecar_filename, expected
row / column counts, is_valid, and bilingual descriptions.
Examples
str(ARSAU_REGISTRY)
#> function ()
Each entry is itself a named list with year_or_range,
kind, csv_filename, sidecar_filename, expected
row / column counts, is_valid, and bilingual descriptions.
str(ARSAU_REGISTRY)
#> function ()