Object-style wrapper for the semiparametric kernel toolkit
Source:R/semipar_bridge.R
SemiparKernels.RdReturns a list of closures bound to the same backend (always pure R in this port; the Python module additionally supports a C backend).
R/semipar_bridge.R
SemiparKernels.RdReturns a list of closures bound to the same backend (always pure R in this port; the Python module additionally supports a C backend).