Skip to contents

Phase 3FFF3. Included snapshot of 157 City-of-Calgary Socrata datasets matched on crime-adjacent keywords (crime, police, fire, ambulance, traffic, incident, collision, bylaw, 311).

Usage

morie_datasets_calgary_open_crime_adjacent_layers(offline = TRUE)

morie_datasets_edmonton_open_crime_adjacent_layers(offline = TRUE)

morie_datasets_ottawa_open_crime_adjacent_layers(offline = TRUE)

Arguments

offline

If TRUE (default), reads the included CSV.

Value

A data.frame with soda_id, title, type, search_keyword.

A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).

A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).

Examples

d <- morie_datasets_calgary_open_crime_adjacent_layers(offline = TRUE)
head(d)
#>     soda_id                      title    type search_keyword
#> 1 78gh-n26t Community Crime Statistics dataset          crime
#> 2 sycx-s5a6  Community Crime Data Lens   story          crime
#> 3 4evm-wx9a Social Disorder Statistics dataset          crime
#> 4 shzx-2b3s           Police Districts     map          crime
#> 5 ap4r-bav3             Police Service dataset          crime
#> 6 86mc-9jh2           Police Districts dataset          crime
cat_df <- morie_datasets_edmonton_open_crime_adjacent_layers()
head(cat_df)
#>     soda_id                                                             title
#> 1 fguc-rs4p         Edmontonians' Perception Survey - Overall Quality Of Life
#> 2 i2x2-wadk                   Edmontonians' Perception Survey - Connectedness
#> 3 72aw-fq6m 2012 Budget Consultation Survey - Satisfaction With City Services
#> 4 3cvu-pkdw                     Vehicle for Hire - Edmonton Insight Community
#> 5 tbsz-v2rj                             Cannabis - Edmonton Insight Community
#> 6 f2ri-59cx              Edmontonians' Perception Survey - Safety In The City
#>      type search_keyword
#> 1 dataset          crime
#> 2 dataset          crime
#> 3 dataset          crime
#> 4 dataset          crime
#> 5 dataset          crime
#> 6 dataset          crime
cat_df <- morie_datasets_ottawa_open_crime_adjacent_layers()
head(cat_df)
#>                             hub_id                  title            type
#> 1 c4e629a525ec44af917fe62bbed9b6cb             Hate Crime Feature Service
#> 2 7b45f3aea40b4c1aa49e62cf78a22590         Overdose Calls Feature Service
#> 3 dc6496aae0e045d4a88d1cd648865e23              Shootings Feature Service
#> 4 5474727b6dae435cb00e656c2e2a5e31 Theft of Motor Vehicle Feature Service
#> 5 26c41557563743ec91a6a94cf88d5799             Bike Theft Feature Service
#> 6 36973da8486143e79ee07e941512200e               Homicide Feature Service
#>           source search_keyword
#> 1 City of Ottawa          crime
#> 2 City of Ottawa          crime
#> 3 City of Ottawa          crime
#> 4 City of Ottawa          crime
#> 5 City of Ottawa          crime
#> 6 City of Ottawa          crime