Skip to contents

Phase 3FFF3. Included 10-row fixture of Edmonton Police Service station locations (Socrata id e7aq-scxv).

Usage

morie_datasets_edmonton_police_stations(offline = TRUE, max_features = NULL)

morie_datasets_edmonton_fire_stations(offline = TRUE, max_features = NULL)

Arguments

offline

If TRUE (default), reads included CSV.

max_features

Optional row cap.

Value

A data.frame with name, address, latitude, longitude.

A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).

Examples

df <- morie_datasets_edmonton_police_stations(offline = TRUE)
df[, c("name", "latitude", "longitude")]
#>                                          name latitude longitude
#> 1        POLICE SERVICES - NORTHEAST DIVISION 53.60504 -113.4173
#> 2               ROYAL CANADIAN MOUNTED POLICE 53.55984 -113.5091
#> 3             POLICE SERVICES - WEST DIVISION 53.53881 -113.6067
#> 4                             RCMP K DIVISION 53.55984 -113.5091
#> 5        POLICE SERVICES - SOUTHEAST DIVISION 53.46000 -113.4267
#> 6  POLICE SERVICES - CALDER COMMUNITY STATION 53.59314 -113.5387
#> 7        POLICE SERVICES - SOUTHWEST DIVISION 53.43401 -113.6162
#> 8               ROYAL CANADIAN MOUNTED POLICE 53.56080 -113.5101
#> 9         POLICE SERVICES - DOWNTOWN DIVISION 53.54771 -113.4848
#> 10                            RCMP K DIVISION 53.56080 -113.5101
df <- morie_datasets_edmonton_fire_stations()
head(df)
#>   latitude longitude                 address name :@computed_region_7ccj_gre3
#> 1 53.42875 -113.4757    1203 ELLWOOD ROAD SW   27                         359
#> 2 53.60135 -113.3869 13808 Victoria Trail NW   18                         144
#> 3 53.55565 -113.5898     10949-156 Street NW    4                           6
#> 4 53.52651 -113.6862          9204 213 ST NW   29                         222
#> 5 53.52882 -113.4920       9315 - 101 Street   21                         366
#> 6 53.45921 -113.5910     131 Haddow Close NW   24                         261
#>   :@computed_region_ecxu_fw7u :@computed_region_izdr_ja4x
#> 1                          81                           9
#> 2                         184                           2
#> 3                         188                           3
#> 4                         158                           3
#> 5                          24                           4
#> 6                          79                           8
#>   :@computed_region_5jki_au6x :@computed_region_mnf4_kaez
#> 1                           7                           4
#> 2                           3                           7
#> 3                           1                           1
#> 4                           4                           1
#> 5                           5                           9
#> 6                           6                          12
#>   :@computed_region_da6r_6gkw
#> 1                          12
#> 2                           4
#> 3                           1
#> 4                           1
#> 5                           6
#> 6                           9