Skip to contents

Phase 3HHH1. Included snapshot of every CKAN package on donnees.montreal.ca – substantially broader than the 23-row Loi/Justice/Securite subset from 3EEE1.

Phase 3HHH2. Included snapshot of every dataset on opendata.vancouver.ca with richer schema (publisher, theme, license, records_count).

Usage

morie_datasets_nyc_opendata_bulk_layers(offline = TRUE)

morie_datasets_chicago_opendata_bulk_layers(offline = TRUE)

morie_datasets_toronto_opendata_bulk_layers(offline = TRUE)

morie_datasets_calgary_opendata_bulk_layers(offline = TRUE)

morie_datasets_edmonton_opendata_bulk_layers(offline = TRUE)

morie_datasets_ottawa_opendata_bulk_layers(offline = TRUE)

morie_datasets_montreal_opendata_bulk_layers(offline = TRUE)

morie_datasets_vancouver_opendata_bulk_layers(offline = TRUE)

Arguments

offline

If TRUE (default), reads included CSV.

Value

Tabular catalog snapshot.

A data.frame.

A data.frame.

A data.frame.

A data.frame.

A data.frame.

A data.frame.

A data.frame.

Examples

d <- morie_datasets_nyc_opendata_bulk_layers(offline = TRUE)
nrow(d)
#> [1] 2851
head(d[, c("soda_id", "type")])
#>     soda_id    type
#> 1 8wbx-tsch dataset
#> 2 vx8i-nprf dataset
#> 3 ic3t-wcy2 dataset
#> 4 dpec-ucu7 dataset
#> 5 xjfq-wh2d dataset
#> 6 erm2-nwe9 dataset
cat_df <- morie_datasets_chicago_opendata_bulk_layers()
head(cat_df)
#>     soda_id                                                 title    type
#> 1 ydr8-5enu                                      Building Permits dataset
#> 2 xzkq-xp2w Current Employee Names, Salaries, and Position Titles dataset
#> 3 dfnk-7re6                                          Crimes - Map     map
#> 4 ijzp-q8t2                              Crimes - 2001 to Present dataset
#> 5 uupf-x98q                    Business Licenses - Current Active  filter
#> 6 85ca-t3if                             Traffic Crashes - Crashes dataset
#>                                                                                                                                                                                                  description
#> 1 <b>Note, 10/15/2025:</b> We have added a PERMIT_CONDITION column.\n\nThis dataset includes information about building permits issued by the City of Chicago from 2006 to the present, excluding permits th
#> 2   This dataset is a listing of all active City of Chicago employees, complete with full names, departments, positions, employment status (part-time or full-time), frequency of hourly employee –where app
#> 3   This dataset reflects reported incidents of crime that have occurred in the City of Chicago over the past year, minus the most recent seven days of data. Data is extracted from the Chicago Police Depa
#> 4   This dataset reflects reported incidents of crime (with the exception of murders where data exists for each victim) that occurred in the City of Chicago from 2001 to present, minus the most recent sev
#> 5                                                                                          Business Licenses with future expiration dates.\n\nSee the source Business Licenses dataset for more information.
#> 6   <b> Note: As of 5/20/2026 we have added IDOT_CONTROL_NO to the dataset.</b> -- Crash data shows information about each traffic crash on city streets within the City of Chicago limits and under the jur
#>                 updated_at page_views_total                  domain_category
#> 1 2026-05-23T12:09:40.000Z          2840098                        Buildings
#> 2 2026-05-24T04:47:55.000Z          2223730         Administration & Finance
#> 3 2026-05-24T10:01:36.000Z          1671001                    Public Safety
#> 4 2026-05-24T11:37:41.000Z          1270613                    Public Safety
#> 5 2026-05-24T05:00:17.000Z          1116002 Community & Economic Development
#> 6 2026-05-24T15:40:26.000Z           826200                   Transportation
cat_df <- morie_datasets_toronto_opendata_bulk_layers()
head(cat_df)
#>                                                                       package_name
#> 1 temporary-extension-and-special-occasion-permit-endorsements-for-liquor-licences
#> 2                                                      multi-tenant-house-licences
#> 3                                                      polls-conducted-by-the-city
#> 4                                           rain-gauge-locations-and-precipitation
#> 5                                                            traffic-signal-timing
#> 6                               daily-shelter-overnight-service-occupancy-capacity
#>                                                                              title
#> 1 Temporary Extension and Special Occasion Permit Endorsements for Liquor Licences
#> 2                                            Multi-Tenant (Rooming) House Licences
#> 3                                                      Polls conducted by the City
#> 4                                           Rain Gauge Locations and Precipitation
#> 5                                                            Traffic Signal Timing
#> 6                           Daily Shelter & Overnight Service Occupancy & Capacity
#>   num_resources          metadata_modified      license
#> 1             8 2026-05-24T15:21:21.040146 notspecified
#> 2             4 2026-05-24T15:14:15.577862 notspecified
#> 3             5 2026-05-24T15:00:15.852619         <NA>
#> 4            14 2026-05-24T14:53:20.403368 notspecified
#> 5             1 2026-05-24T14:15:14.080166 notspecified
#> 6            24 2026-05-24T13:35:55.941361 notspecified
cat_df <- morie_datasets_calgary_opendata_bulk_layers()
head(cat_df)
#>     soda_id                                   title    type
#> 1 35ra-9556                       Traffic Incidents dataset
#> 2 c2es-76ed                        Building Permits dataset
#> 3 jq4t-b745 Waste and Recycling Collection Schedule dataset
#> 4 vdjc-pybd               Calgary Business Licenses dataset
#> 5 rbfp-3tic                        Speed Limits Map     map
#> 6 k7p9-kppz                         Traffic Cameras dataset
#>                                                                                                                                                                                                  description
#> 1   This is an unofficial archive of traffic incidents within Calgary. Traffic incidents are traffic disruptions affecting traffic flow, such as traffic signal issues, hazardous road conditions, stalled v
#> 2 Building permit applications made to The City of Calgary's Planning & Development department. \nFor general requests please contact propertyresearch@calgary.ca.\nVisit the Calgary.ca <a href="http://www
#> 3   To look up your address, download a calendar, or get a reminder for your next pickup date, visit:  <a href="http://www.calgary.ca/UEP/WRS/Pages/Garbage-collection-information/Residential-services/Garb
#> 4   This file includes the licensed businesses in the City of Calgary. Data fields include: Trade name, Business Location, Creation Date, Status, Licence Type and Community District of the business. All b
#> 5   This dataset lists the maximum speed limits throughout Calgary. It does not list the default residential speed limit of 40 km/hr, which is being reduced from 50 km/h to 40 km/h effective May 31, 2021.
#> 6   View up-to-the-minute traffic camera images of current road conditions on major routes as well as other key intersections. *These cameras are solely for traffic monitoring and not enforcement. Camera 
#>                 updated_at page_views_total                domain_category
#> 1 2026-05-24T16:31:02.000Z           597486         Transportation/Transit
#> 2 2026-05-23T19:03:30.000Z           308591 Business and Economic Activity
#> 3 2026-05-22T23:43:07.000Z           107602         Services and Amenities
#> 4 2026-05-24T05:14:53.000Z           104393 Business and Economic Activity
#> 5 2026-05-01T19:01:36.000Z           103083              Health and Safety
#> 6 2026-05-24T02:51:00.000Z            82080         Transportation/Transit
cat_df <- morie_datasets_edmonton_opendata_bulk_layers()
head(cat_df)
#>     soda_id
#> 1 ex39-rsw7
#> 2 24uj-dj8v
#> 3 mhbf-f3zb
#> 4 qkyj-dqjp
#> 5 q35u-fg2i
#> 6 kiw9-p7ha
#>                                                                    title
#> 1 COVID-19 in Alberta: Current cases by local geographic area (Map View)
#> 2                                               General Building Permits
#> 3                                                Traffic Disruptions Map
#> 4                               COVID-19 in Edmonton: Daily Active Cases
#> 5                                  Scheduled Automated Enforcement Zones
#> 6                                            Intersection Safety Devices
#>      type
#> 1     map
#> 2 dataset
#> 3     map
#> 4   chart
#> 5   story
#> 6   story
#>                                                                                                                                                                                                  description
#> 1 Current COVID-19 cases in Alberta, by local geographic area.\n\n    This is a mirror of the data presented in the map view at https://www.alberta.ca/stats/covid-19-alberta-statistics.htm ('Geospatial' t
#> 2   List of issued building permits from the City of Edmonton - Urban Planning & Economy Department for the public to do construction or maintenance on a structure located in the City. Note - All records 
#> 3  This dataset provides information about what's happening on Edmonton's roads that could impact your drive, including: \nMajor road closures and detours, Road construction, Travel delays and special eve
#> 4   COVID-19 data for Edmonton:\n    \n    From https://www.alberta.ca/covid-19-alberta-data.aspx:\n      - Previous day's Confirmed Cases, Active Cases, Recovered Cases, In Hospital, In Intensive Care, D
#> 5                                                  Superseded: Please visit the Safe Streets Map at https://gis.edmonton.ca/portal/apps/instant/minimalist/index.html?appid=605857c965cf43b0aa98f2d9ed7f0653
#> 6                                                  Superseded: please visit the Safe Streets Map at https://gis.edmonton.ca/portal/apps/instant/minimalist/index.html?appid=605857c965cf43b0aa98f2d9ed7f0653
#>                 updated_at page_views_total          domain_category
#> 1 2022-09-28T22:09:11.000Z           196438       Community Services
#> 2 2026-05-24T10:20:03.000Z           140230 Urban Planning & Economy
#> 3 2026-05-24T16:02:54.000Z           128386           Transportation
#> 4 2023-08-29T21:15:29.000Z           108708       Community Services
#> 5 2022-08-02T18:10:09.842Z           101939           Transportation
#> 6 2022-08-02T18:12:29.862Z            98847           Transportation
cat_df <- morie_datasets_ottawa_opendata_bulk_layers()
head(cat_df)
#>                             hub_id
#> 1 cd6620f68d654e88b4aa1f6e0024c3f6
#> 2 58ed97efc38d48969199556e29f7c96c
#> 3 0b1c99e228254eb5993caebb806636f3
#> 4 2cdd1bf5ef824d358222aba3e743af84
#> 5 c8fc7fe6b0594eb3b4c93d6c44a7fb54
#> 6 f6b1b5c8b68845b8afefdd1110c6d906
#>                                                                                                                             title
#> 1                                                                                             2025 Draft Budget Explorer Datasets
#> 2                                                                                               2024 Draft Budget Tool - Datasets
#> 3                                                                                                      Recreation Guide 2022 Fall
#> 4                                    Climate Projections for the National Capital Region - Appendix G - Tables of Climate Indices
#> 5 Climate Projections for the National Capital Region - Table 2.1 Projections for Extreme Precipitation Based on Multiple Methods
#> 6                                                                                                   2022 Monthly Service Requests
#>             type         source license
#> 1 CSV Collection City of Ottawa  custom
#> 2 CSV Collection City of Ottawa  custom
#> 3 CSV Collection City of Ottawa  custom
#> 4 CSV Collection City of Ottawa  custom
#> 5 CSV Collection City of Ottawa  custom
#> 6 CSV Collection City of Ottawa  custom
cat_df <- morie_datasets_montreal_opendata_bulk_layers()
head(cat_df)
#>                                   package_name
#> 1                      rsqa-indice-qualite-air
#> 2 frequentation-du-portail-de-donnees-ouvertes
#> 3                 nombre-telechargment-donnees
#> 4                                  requete-311
#> 5                                    cyclistes
#> 6              depistage-entrees-service-plomb
#>                                                                             title
#> 1                     RSQA - indice de la qualité de l'air temps réel (quotidien)
#> 2                                    Fréquentation du portail de données ouvertes
#> 3   Téléchargement quotidien des ressources à partir du site des Données ouvertes
#> 4                                  Demandes de services citoyennes (Requêtes 311)
#> 5                                                  Compteurs cyclistes permanents
#> 6 Résultats du dépistage des entrées de service en plomb réalisé par un Palintest
#>   num_resources          metadata_modified language license
#> 1             3 2026-05-24T17:47:25.254479       FR   cc-by
#> 2             3 2026-05-24T17:03:00.237449       FR   cc-by
#> 3             1 2026-05-24T17:01:31.423103       FR   cc-by
#> 4             6 2026-05-24T12:06:06.535364       FR   cc-by
#> 5             1 2026-05-24T11:01:27.218803       FR   cc-by
#> 6             2 2026-05-24T08:31:53.303349       FR   cc-by
cat_df <- morie_datasets_vancouver_opendata_bulk_layers()
head(cat_df)
#>                                                                         dataset_id
#> 1                               2019-2022-capital-plan-and-2021-budget-and-funding
#> 2  2021-new-multi-year-capital-budget-requests-and-2021-capital-expenditure-budget
#> 3  2022-new-multi-year-capital-budget-requests-and-2022-capital-expenditure-budget
#> 4 2023-2026-capital-plan-and-2023-capital-budget-with-proposed-four-year-capital-p
#> 5 2023-2026-capital-plan-and-2024-capital-budget-with-proposed-four-year-capital-0
#> 6 2023-2026-capital-plan-and-2025-capital-budget-with-proposed-four-year-capital-0
#>                                                                                             title
#> 1                                              2019-2022 Capital Plan and 2021 Budget and funding
#> 2                 2021 new Multi-Year Capital Budget requests and 2021 Capital Expenditure Budget
#> 3                 2022 new Multi-Year Capital Budget requests and 2022 Capital Expenditure Budget
#> 4 2023-2026 Capital Plan and 2023 Capital Budget with proposed four-year Capital Plan allocations
#> 5 2023-2026 Capital Plan and 2024 Capital Budget with proposed four-year Capital Plan allocations
#> 6 2023-2026 Capital Plan and 2025 Capital Budget with proposed four-year Capital Plan allocations
#>           publisher records_count                             license
#> 1 City of Vancouver           238 Open Government Licence - Vancouver
#> 2 City of Vancouver           496 Open Government Licence - Vancouver
#> 3 City of Vancouver           548 Open Government Licence - Vancouver
#> 4 City of Vancouver           336 Open Government Licence - Vancouver
#> 5 City of Vancouver           349 Open Government Licence - Vancouver
#> 6 City of Vancouver           362 Open Government Licence - Vancouver
#>                    theme
#> 1 Government and finance
#> 2 Government and finance
#> 3 Government and finance
#> 4 Government and finance
#> 5 Government and finance
#> 6 Government and finance