Skip to contents

OTIS c02 – Individuals by institution

Usage

morie_datasets_otis_c02_individuals_by_institution(
  offline = TRUE,
  resource_id = NULL,
  source = NULL
)

Arguments

offline

If TRUE (default), read the included synthetic fixture. If FALSE, hit Ontario CKAN (resource_id required).

resource_id

Optional CKAN resource id (required for live).

source

One of NULL (default, ships an empty 0-row frame with the documented schema when no real CKAN row is included), "real" (force the real CKAN sample included in inst/extdata/, error if absent), or "synth" (return a deterministic set.seed() synthetic for didactic examples).

Value

A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).

Examples

df <- morie_datasets_otis_c02_individuals_by_institution(offline = TRUE)
head(df)
#>   EndFiscalYear Region_MostRecentPlacement Institution_MostRecentPlacement
#> 1          2022                    Toronto             SYNTH Institution 1
#> 2          2023                    Eastern             SYNTH Institution 2
#> 3          2023                    Central             SYNTH Institution 3
#> 4          2024                    Western             SYNTH Institution 4
#> 5          2024                   Northern             SYNTH Institution 5
#>   Gender NumberIndividuals_RestrictiveConfinement NumberIndividuals_Segregation
#> 1   Male                                       60                            40
#> 2 Female                                        8                             5
#> 3   Male                                       35                            22
#> 4 Female                                       12                             8
#> 5   Male                                       45                            30