Skip to contents

Phase 3DDD2. Returns the legal disclaimer text shipped with VPD's open crime data download. Useful in headless or programmatic workflows where the human reader of the GeoDASH web UI is not the same as the script user.

Usage

morie_datasets_vpd_legal_disclaimer()

Value

A character vector (one element per line).