Skip to contents

Folds the real cepstrum to the causal half then re-exponentiates to produce a minimum-phase sequence with the same magnitude spectrum as x (approximate).

Usage

morie_dsp_min_phase(x)

Arguments

x

Numeric vector.

Value

Numeric vector, length(x).

References

Rangayyan & Krishnan (2015), Ch. 5; Oppenheim & Schafer (2010).

Examples

set.seed(1)
x <- sin(2 * pi * 0.05 * (1:128)) + rnorm(128, 0, 0.1)
str(morie_dsp_min_phase(x), max.level = 1)
#>  num [1:128] 1.37 1.38 1.78 1.82 1.82 ...