Skip to contents

Calls the CKAN resource_show verb to resolve a resource id into its download URL plus metadata.

Usage

morie_ingest_ckan_resource_show(
  portal,
  resource_id,
  api_key = NULL,
  user_agent = .MORIE_CKAN_DEFAULT_UA,
  timeout = .MORIE_CKAN_DEFAULT_TIMEOUT
)

Arguments

portal

Base URL of the CKAN portal.

resource_id

CKAN resource id (UUID).

api_key

Optional CKAN API key.

user_agent

User-Agent header sent with the request.

timeout

HTTP timeout in seconds.

Value

The resource metadata list.

Examples

# \donttest{
try(morie_ingest_ckan_resource_show(
  "https://data.ontario.ca",
  "ea9dc29c-b4f1-4426-b1f2-974ce995aca1"))
#> $`_skip_next_validation`
#> $`_skip_next_validation`[[1]]
#> [1] TRUE
#> 
#> 
#> $cache_last_updated
#> NULL
#> 
#> $cache_url
#> NULL
#> 
#> $ckan_url
#> [1] "https://data.ontario.ca"
#> 
#> $created
#> [1] "2025-08-29T20:01:26.133775"
#> 
#> $data_last_updated
#> [1] "2025-08-29"
#> 
#> $data_range_end
#> [1] "2024-12-31"
#> 
#> $data_range_start
#> [1] "2024-01-01"
#> 
#> $datastore_active
#> [1] TRUE
#> 
#> $datastore_contains_all_records_of_source_file
#> [1] TRUE
#> 
#> $description
#> [1] "This dataset is one of the four datasets that comprise the Police Use of Force database. Depending on the scope of the analysis, linking between datasets may be necessary.\r\nThis particular dataset provides core information, at the report-level, on provincially reportable police use of force incidents that occurred in 2024.\r\nSome variables within this dataset were either too granular or considered sensitive (e.g., open-text variables), therefore presenting an increased risk of re-identification either on their own or when combined with other publicly available information. These variables have been generalized or removed to ensure privacy.\r\nFor more details on this dataset, please refer to the related data dictionary and technical report.  \r\n\r\n\r\n__Note:__ This dataset may be updated periodically to reflect new submissions, amendments or corrections. For details on data updates and version history, please consult the available metadata such as data dictionary and supporting documentation.\r\n\r\n\r\nVersion 1.0.  \r\nData as of July 08, 2025.  \r\nThe dataset follows the UTF-8 encoding standard."
#> 
#> $description_translated
#> $description_translated$en
#> [1] "This dataset is one of the four datasets that comprise the Police Use of Force database. Depending on the scope of the analysis, linking between datasets may be necessary.\r\nThis particular dataset provides core information, at the report-level, on provincially reportable police use of force incidents that occurred in 2024.\r\nSome variables within this dataset were either too granular or considered sensitive (e.g., open-text variables), therefore presenting an increased risk of re-identification either on their own or when combined with other publicly available information. These variables have been generalized or removed to ensure privacy.\r\nFor more details on this dataset, please refer to the related data dictionary and technical report.  \r\n\r\n\r\n__Note:__ This dataset may be updated periodically to reflect new submissions, amendments or corrections. For details on data updates and version history, please consult the available metadata such as data dictionary and supporting documentation.\r\n\r\n\r\nVersion 1.0.  \r\nData as of July 08, 2025.  \r\nThe dataset follows the UTF-8 encoding standard."
#> 
#> $description_translated$fr
#> [1] "Cet ensemble de données est l’un des quatre ensembles de données qui composent la base de données sur le recours à la force par la police. Selon la portée de l’analyse, il pourrait être nécessaire d’établir des liens entre les ensembles de données.\r\nCet ensemble de données particulier fournit des renseignements de base, au niveau du rapport, sur les incidents provinciaux de recours à la force par les policiers ayant fait l’objet d’une déclaration et qui se sont produits en 2024.\r\nCertaines variables de cet ensemble de données étaient soit trop granulaires, soit considérées comme sensibles (par exemple, les variables en texte libre), et présentaient donc un risque accru de réidentification, soit seules, soit en combinaison avec d’autres renseignements accessibles au public. Ces variables ont été généralisées ou retirées pour garantir la protection de la vie privée.\r\nPour obtenir davantage de renseignements sur cet ensemble de données, veuillez consulter le dictionnaire de données et le rapport technique connexes.  \r\n\r\n\r\n__Note:__ Cet ensemble de données peut être mis à jour périodiquement pour refléter de nouvelles soumissions, des amendements ou des corrections. Pour plus de détails sur les mises à jour des données et l'historique des versions, veuillez consulter les métadonnées disponibles telles que le dictionnaire de données et la documentation d'appui. \r\n\r\n\r\nVersion 1.0.  \r\nDonnées au 08 juillet 2025.  \r\nL'ensemble de données respecte la norme d'encodage UTF-8."
#> 
#> 
#> $format
#> [1] "CSV"
#> 
#> $hash
#> [1] "fe86da1951ca9039c11a73c56c8c56d3"
#> 
#> $id
#> [1] "ea9dc29c-b4f1-4426-b1f2-974ce995aca1"
#> 
#> $ignore_hash
#> [1] TRUE
#> 
#> $language
#> [1] "english"
#> 
#> $last_modified
#> [1] "2025-10-08T18:58:37.253929"
#> 
#> $metadata_modified
#> [1] "2025-10-08T19:00:38.321816"
#> 
#> $mimetype
#> [1] "application/csv"
#> 
#> $mimetype_inner
#> NULL
#> 
#> $name
#> [1] "Police Use of Force – Main Records, 2024"
#> 
#> $name_translated
#> $name_translated$en
#> [1] "Police Use of Force – Main Records, 2024"
#> 
#> $name_translated$fr
#> [1] "Recours à la force par la police –  Principaux dossiers, 2024"
#> 
#> 
#> $original_url
#> [1] "https://data.ontario.ca/dataset/324ff147-816c-4143-a414-d1e973dca140/resource/ea9dc29c-b4f1-4426-b1f2-974ce995aca1/download/uof_main_records.csv"
#> 
#> $package_id
#> [1] "324ff147-816c-4143-a414-d1e973dca140"
#> 
#> $position
#> [1] 0
#> 
#> $publically_available_date
#> [1] "2025-08-29"
#> 
#> $resource_id
#> [1] "ea9dc29c-b4f1-4426-b1f2-974ce995aca1"
#> 
#> $resource_type
#> NULL
#> 
#> $schema
#> [1] ""
#> 
#> $set_url_type
#> [1] FALSE
#> 
#> $size
#> [1] 2549959
#> 
#> $state
#> [1] "active"
#> 
#> $task_created
#> [1] "2025-10-08 19:00:39.445654"
#> 
#> $type
#> [1] "data"
#> 
#> $url
#> [1] "https://data.ontario.ca/dataset/324ff147-816c-4143-a414-d1e973dca140/resource/ea9dc29c-b4f1-4426-b1f2-974ce995aca1/download/uof_main_records.csv"
#> 
#> $url_type
#> [1] "upload"
#> 
#> $validation_options
#> [1] ""
#> 
#> $validation_status
#> [1] "success"
#> 
#> $validation_timestamp
#> [1] "2025-10-08T19:00:38.063406"
#> 
# }