Skip to contents

Stock-Yogo critical values

Usage

morie_iv_stock_yogo(n_endogenous = 1, n_instruments = 1)

Arguments

n_endogenous

Integer; number of endogenous regressors used to look up the Stock-Yogo critical-value table.

n_instruments

Integer; number of instruments used to look up the Stock-Yogo critical-value table.

Value

A named list of Stock-Yogo weak-instrument critical values.

Examples

out <- morie_iv_stock_yogo(n_endogenous = 1, n_instruments = 1)
out
#> $`10pct`
#> [1] 16.38
#> 
#> $`15pct`
#> [1] 8.96
#> 
#> $`20pct`
#> [1] 6.66
#> 
#> $`25pct`
#> [1] 5.53
#>