Skip to contents

Computes the conditional-variance Abadie-Imbens SE accounting for the fact that matching introduces correlation across matched observations.

Usage

morie_matching_abadie_imbens_se(
  data,
  outcome,
  treatment,
  match_pairs,
  n_matches = 1L
)

Arguments

data

Data frame.

outcome, treatment

Column names.

match_pairs

Data frame of matched indices.

n_matches

Number of matches per treated unit (carried for parity).

Value

Scalar numeric Abadie-Imbens SE.

References

Abadie, A., & Imbens, G. W. (2006). Large sample properties of matching estimators for average treatment effects. Econometrica, 74(1), 235–267.

Examples

# \donttest{
set.seed(1)
df <- data.frame(y = rnorm(200), d = rbinom(200, 1, 0.4),
                 x1 = rnorm(200), x2 = rnorm(200))
res <- morie_matching_nearest_neighbor(df, "d", c("x1", "x2"))
morie_matching_abadie_imbens_se(df, "y", "d", res$match_pairs)
#> [1] 0.1313231
# }