Restrict a sample to the region of common support
Source:R/matching.R
morie_matching_common_support.RdDrops units whose propensity score falls outside the overlap region of treated and control units.
Usage
morie_matching_common_support(
data,
treatment,
ps_col = "propensity_score",
method = "minmax"
)Examples
if (FALSE) { # \dontrun{
df$propensity_score <- morie_matching_estimate_propensity(df, "d",
c("x1", "x2"))
morie_matching_common_support(df, "d")
} # }