Estimates the probability of treatment via logistic regression or gradient boosting on a set of covariates.
Usage
morie_matching_estimate_propensity(
data,
treatment,
covariates,
model = "logistic",
max_iter = 1000
)Value
A numeric vector of propensity scores aligned to the rows of
data (after dropping NAs in treatment or
covariates); the names of the vector are the row names
of the retained rows.