Skip to contents

Thin extender over performance::check_outliers for composite outlier detection on a fitted model or numeric data.

Usage

morie_performance_check_outliers(x, ...)

Arguments

x

A fitted model object or numeric data frame supported by performance::check_outliers.

...

Further arguments forwarded to performance::check_outliers (e.g. method, threshold).

Value

A list with $method = "performance::check_outliers" and $raw (the upstream outlier-check object).

Examples

if (requireNamespace("performance", quietly = TRUE)) {
  set.seed(1)
  df <- data.frame(y = c(rnorm(49), 8), x = rnorm(50))
  morie_performance_check_outliers(stats::lm(y ~ x, df))
}
#> $method
#> [1] "performance::check_outliers"
#> 
#> $raw
#> 1 outlier detected: case 50.
#> - Based on the following method and threshold: cook (0.703).
#> - For variable: (Whole model).
#>