Skip to contents

Thin interface to konfound::pkonfound: how many cases would need to be replaced with average-treatment-effect cases (or how large would an omitted-variable correlation have to be) to invalidate the inference? Pairs with morie_sensitivity_omitted_var_bias (which uses the Cinelli-Hazlett partial-R-squared framing instead of the Frank et al. percent-bias-to-invalidate framing).

Usage

morie_sensitivity_konfound(
  estimate,
  se,
  n,
  n_covariates = 0L,
  alpha = 0.05,
  ...
)

Arguments

estimate

Treatment-coefficient estimate.

se

Standard error of estimate.

n

Number of observations.

n_covariates

Number of covariates in the model (excluding the intercept and the treatment). Default 0.

alpha

Significance level. Default 0.05.

...

Additional arguments forwarded to konfound::pkonfound.

Value

A list of class morie_sensitivity_konfound with the percent-bias-to-invalidate, the impact-threshold-of-a- confounding-variable (ITCV), and the raw konfound object.

References

Frank, K. A., Maroulis, S. J., Duong, M. Q., & Kelcey, B. M. (2013). What would it take to change an inference? Educational Evaluation and Policy Analysis, 35(4), 437–460.

Examples

str(morie_sensitivity_konfound(0.5, 0.15, 200), max.level = 1)
#> Warning: `aes_string()` was deprecated in ggplot2 3.0.0.
#>  Please use tidy evaluation idioms with `aes()`.
#>  See also `vignette("ggplot2-in-packages")` for more information.
#>  The deprecated feature was likely used in the konfound package.
#>   Please report the issue at
#>   <https://github.com/konfound-project/konfound/issues>.
#> Warning: Using `size` aesthetic for lines was deprecated in ggplot2 3.4.0.
#>  Please use `linewidth` instead.
#>  The deprecated feature was likely used in the konfound package.
#>   Please report the issue at
#>   <https://github.com/konfound-project/konfound/issues>.
#> For interpretation, check out to_return = 'print'.
#> List of 7
#>  $ estimate                   : num 0.5
#>  $ se                         : num 0.15
#>  $ n                          : num 200
#>  $ percent_bias_to_invalidate : num(0) 
#>  $ impact_threshold_confounder: num 0.107
#>  $ method                     : chr "pkonfound (konfound)"
#>  $ raw                        :List of 18
#>  - attr(*, "class")= chr [1:2] "morie_sensitivity_konfound" "list"