Skip to contents

Operationalizes UN Mandela Rules 43 and 44 against a single SIU person-stay's days, average hours out of cell, and percent- of-days that missed the legislatively-required 4 hours out of cell.

Usage

morie_siu_classify_mandela(
  days_in_siu,
  hrs_out_of_cell_avg,
  missed_full_4hrs_pct_of_days
)

Arguments

days_in_siu

Length of the stay (days).

hrs_out_of_cell_avg

Average hours out of cell per day during the stay.

missed_full_4hrs_pct_of_days

Percent of days (0-100) where the inmate did not receive the legislatively-required 4 hours out of cell.

Value

A named list with elements category, rule, and reason.

Details

  • Solitary Confinement (Rule 44): <=2 hrs avg out of cell, missed full 4 hrs every day, stay <=15 days.

  • Torture (Rules 43+44): same conditions but stay length >=16 days (crosses the "prolonged" threshold).

  • All other: did not meet either threshold.

Examples

morie_siu_classify_mandela(20, 1.5, 100)$category
#> [1] "Torture"
morie_siu_classify_mandela(8, 1.5, 100)$category
#> [1] "Solitary Confinement"
morie_siu_classify_mandela(20, 5, 50)$category
#> [1] "All other"