Returns a survey::svydesign object when survey is available; otherwise
returns a lightweight list with the same fields the morie helpers consume.
Returns a survey::svydesign object when survey is available; otherwise
returns a lightweight list with the same fields the morie helpers consume.