Delegates to survival::survfit() with Surv(left, right, type = "interval2").
Hand-rolled EM is left as a stub for environments without survival.
Delegates to survival::survfit() with Surv(left, right, type = "interval2").
Hand-rolled EM is left as a stub for environments without survival.