Counts local maxima and minima and compares to the expectation
\(2(n-2)/3\) under randomness. Reproduces
randtests::turning.point.test.
Counts local maxima and minima and compares to the expectation
\(2(n-2)/3\) under randomness. Reproduces
randtests::turning.point.test.