Summary table of causal effect estimates from multiple estimators
Source:R/tables_pub.R
treatment_effect_table.RdSummary table of causal effect estimates from multiple estimators
R/tables_pub.R
treatment_effect_table.RdSummary table of causal effect estimates from multiple estimators