Tests are evaluated in the given order and the procedure stops at the first non-rejection; reached hypotheses need no multiplicity adjustment. The gMCP package implements the equivalent procedure via a chain graph.
Tests are evaluated in the given order and the procedure stops at the first non-rejection; reached hypotheses need no multiplicity adjustment. The gMCP package implements the equivalent procedure via a chain graph.