NIST Reference Datasets (RDS) catalog metadata.
Usage
morie_datasets_nist_rds(
dataset_id = NULL,
query = NULL,
max_features = NULL,
offline = FALSE
)Examples
df <- morie_datasets_nist_rds(offline = TRUE)
#> Warning: morie_datasets_nist_rds(offline=TRUE): using the bundled synthetic nist_rds frame. This is a toy dataset with the documented schema but random data; do not interpret outputs as findings about the real population.
head(df)
#> id
#> 1 ark:/88434/mds00ch8q4
#> 2 ark:/88434/mds007zd70
#> 3 ark:/88434/mds00xdk4z
#> 4 ark:/88434/mds00j8tfn
#> 5 ark:/88434/mds007htv8
#> 6 ark:/88434/mds019ft36
#> title
#> 1 Dataset from Fire Safety Challenges of Tall Wood Buildings - Phase 2: Task 3 - Cross Laminated Timber Compartment Fire Tests
#> 2 SRM 895 Stainless Steel (SAE 201)
#> 3 NIST Ionic Liquids Database - (ILThermo) - SRD 147
#> 4 NIST Synthetic Polymer MALDI MS Methods Database - SRD 172
#> 5 SRM 3235 Soy Milk
#> 6 SRM 671 Nickel Oxide No. 1
#> description issued modified publisher
#> 1 NA <NA> 2018-02-15 National Institute of Standards and Technology
#> 2 NA <NA> 2017-01-05 National Institute of Standards and Technology
#> 3 NA <NA> 2016-07-07 National Institute of Standards and Technology
#> 4 NA <NA> 2013-01-01 National Institute of Standards and Technology
#> 5 NA <NA> 2015-08-27 National Institute of Standards and Technology
#> 6 NA <NA> 2017-01-05 National Institute of Standards and Technology
#> version doi
#> 1 1.0.0 <NA>
#> 2 1.0.0 <NA>
#> 3 1.0.0 <NA>
#> 4 1.0.0 <NA>
#> 5 1.0.0 <NA>
#> 6 1.0.0 <NA>