OTIS b05 – Segregation placements by consecutive-length bucket
Source:R/datasets_ontario_tps.R
morie_datasets_otis_b05_seg_consecutive_lengths.RdOTIS b05 – Segregation placements by consecutive-length bucket
Usage
morie_datasets_otis_b05_seg_consecutive_lengths(
offline = TRUE,
resource_id = NULL,
source = NULL
)Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_b05_seg_consecutive_lengths(offline = TRUE)
head(df)
#> EndFiscalYear Consecutive_Duration Number_SegregationPlacements
#> 1 2022 1 to 7 days 120
#> 2 2022 8 to 15 days 45
#> 3 2023 16 to 30 days 18
#> 4 2023 31 to 60 days 7
#> 5 2024 Over 60 days 3