OTIS b09 – Individuals in segregation by number of times placed
Source:R/datasets_ontario_tps.R
morie_datasets_otis_b09_seg_n_times.RdOTIS b09 – Individuals in segregation by number of times placed
Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_b09_seg_n_times(offline = TRUE)
head(df)
#> EndFiscalYear NumberPlacements_Segregation Gender
#> 1 2022 1 Male
#> 2 2022 2 Female
#> 3 2023 3 Male
#> 4 2023 4 Female
#> 5 2024 5 or more Male
#> NumberIndividuals_Segregation
#> 1 280
#> 2 45
#> 3 30
#> 4 12
#> 5 18