OTIS c01 – Total individuals (in custody / restrictive confinement / segregation)
Source:R/datasets_ontario_tps.R
morie_datasets_otis_c01_individuals_total.RdOTIS c01 – Total individuals (in custody / restrictive confinement / segregation)
Usage
morie_datasets_otis_c01_individuals_total(
offline = TRUE,
resource_id = NULL,
source = NULL
)Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_c01_individuals_total(offline = TRUE)
head(df)
#> EndFiscalYear Gender NumberIndividuals_InCustody
#> 1 2022 Male 8000
#> 2 2022 Female 600
#> 3 2023 Male 8200
#> 4 2023 Female 620
#> 5 2024 Male 7900
#> NumberIndividuals_RestrictiveConfinement NumberIndividuals_Segregation
#> 1 400 280
#> 2 30 22
#> 3 420 295
#> 4 28 24
#> 5 410 270