OTIS c04 – Individuals by race x region
Source:R/datasets_ontario_tps.R
morie_datasets_otis_c04_individuals_race_by_region.RdOTIS c04 – Individuals by race x region
Usage
morie_datasets_otis_c04_individuals_race_by_region(
offline = TRUE,
resource_id = NULL,
source = NULL
)Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_c04_individuals_race_by_region(offline = TRUE)
head(df)
#> EndFiscalYear Region_MostRecentPlacement Race
#> 1 2022 Toronto White
#> 2 2023 Eastern Indigenous
#> 3 2023 Central Black
#> 4 2024 Western South Asian
#> 5 2024 Northern Other
#> NumberIndividuals_RestrictiveConfinement NumberIndividuals_Segregation
#> 1 80 55
#> 2 60 45
#> 3 40 28
#> 4 25 18
#> 5 15 10