OTIS c08 – Individuals by religion x gender
Source:R/datasets_ontario_tps.R
morie_datasets_otis_c08_individuals_religion_by_gender.RdOTIS c08 – Individuals by religion x gender
Usage
morie_datasets_otis_c08_individuals_religion_by_gender(
offline = TRUE,
resource_id = NULL,
source = NULL
)Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_c08_individuals_religion_by_gender(offline = TRUE)
head(df)
#> EndFiscalYear Religion Gender NumberIndividuals_InCustody
#> 1 2022 Christian Male 2200
#> 2 2022 Muslim Male 600
#> 3 2023 No religion Female 200
#> 4 2023 Other Male 1100
#> 5 2024 Indigenous Spirituality Female 80
#> NumberIndividuals_RestrictiveConfinement NumberIndividuals_Segregation
#> 1 120 85
#> 2 40 28
#> 3 15 10
#> 4 65 45
#> 5 8 6