OTIS c09 – Individuals by age category x gender
Source:R/datasets_ontario_tps.R
morie_datasets_otis_c09_individuals_age_by_gender.RdOTIS c09 – Individuals by age category x gender
Usage
morie_datasets_otis_c09_individuals_age_by_gender(
offline = TRUE,
resource_id = NULL,
source = NULL
)Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_c09_individuals_age_by_gender(offline = TRUE)
head(df)
#> EndFiscalYear Age_Category Gender NumberIndividuals_InCustody
#> 1 2022 18 to 24 Male 1500
#> 2 2022 25 to 49 Female 250
#> 3 2023 50 to 64 Male 800
#> 4 2023 65 and over Female 100
#> 5 2024 25 to 49 Male 4200
#> NumberIndividuals_RestrictiveConfinement NumberIndividuals_Segregation
#> 1 90 60
#> 2 18 12
#> 3 50 35
#> 4 8 5
#> 5 240 160