OTIS c10 – Aggregate durations by institution
Source:R/datasets_ontario_tps.R
morie_datasets_otis_c10_aggregate_durations_by_institution.RdOTIS c10 – Aggregate durations by institution
Usage
morie_datasets_otis_c10_aggregate_durations_by_institution(
offline = TRUE,
resource_id = NULL,
source = NULL
)Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_c10_aggregate_durations_by_institution(offline = TRUE)
names(df)
#> [1] "EndFiscalYear"
#> [2] "Region_MostRecentPlacement"
#> [3] "Institution_MostRecentPlacement"
#> [4] "Gender"
#> [5] "Measure"
#> [6] "TotalAggregatedDays_RestrictiveConfinement"
#> [7] "TotalAggregatedDays_Segregation"