OTIS c11 – Aggregate lengths
Source:R/datasets_ontario_tps.R
morie_datasets_otis_c11_aggregate_lengths.RdOTIS c11 – Aggregate lengths
Usage
morie_datasets_otis_c11_aggregate_lengths(
offline = TRUE,
resource_id = NULL,
source = NULL
)Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_c11_aggregate_lengths(offline = TRUE)
head(df)
#> EndFiscalYear Aggregate_Duration NumberIndividuals_RestrictiveConfinement
#> 1 2022 1 to 15 days 180
#> 2 2022 16 to 30 days 80
#> 3 2023 31 to 60 days 50
#> 4 2023 61 to 90 days 25
#> 5 2024 Over 90 days 18
#> NumberIndividuals_Segregation
#> 1 120
#> 2 55
#> 3 30
#> 4 14
#> 5 8