OTIS d02 – Deaths in custody by gender
Source:R/datasets_ontario_tps.R
morie_datasets_otis_d02_deaths_by_gender.RdOTIS d02 – Deaths in custody by gender
Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_d02_deaths_by_gender(offline = TRUE)
head(df)
#> Year Gender Number_CustodialDeaths
#> 1 2022 Male 28
#> 2 2022 Female 3
#> 3 2023 Male 31
#> 4 2023 Female 4
#> 5 2024 Male 25