OTIS d06 – Deaths in custody by alert type x institution
Source:R/datasets_ontario_tps.R
morie_datasets_otis_d06_cause_by_alert.RdOTIS d06 – Deaths in custody by alert type x institution
Arguments
- offline
If
TRUE(default), read the included synthetic fixture. IfFALSE, hit Ontario CKAN (resource_idrequired).- resource_id
Optional CKAN resource id (required for live).
- source
One of
NULL(default, ships an empty 0-row frame with the documented schema when no real CKAN row is included),"real"(force the real CKAN sample included ininst/extdata/, error if absent), or"synth"(return a deterministicset.seed()synthetic for didactic examples).
Value
A data.frame of the requested dataset (a 0-row typed frame when the data is unavailable offline).
Examples
df <- morie_datasets_otis_d06_cause_by_alert(offline = TRUE)
head(df)
#> Year Alert_Type MedicalCauseOfDeath Number_CustodialDeaths
#> 1 2022 Mental Health Alert Drug Toxicity 3
#> 2 2022 Suicide Risk Alert Self-Inflicted 2
#> 3 2023 Mental Health Alert Natural 8
#> 4 2023 None Natural 12
#> 5 2024 Mental Health Alert Drug Toxicity 5