Skip to contents

Use this when you want to pass a name as a string and avoid the unquoted-symbol capture behaviour of morie_describe.

Usage

morie_describe_by_name(name)

Arguments

name

Character scalar, the callable's mnemonic name (with or without the morie_ prefix).

Value

Invisibly returns the narrative as a character scalar. If no matching describe entry is found, returns NULL and prints a helpful diagnostic.

Examples

if (FALSE) { # \dontrun{
morie_describe_by_name("aalen")
morie_describe_by_name("morie_aalen")
} # }