Uses \(Z \times \mathrm{Post}\) as an instrument for \(D \times \mathrm{Post}\) to recover a local average treatment effect under imperfect compliance.
Usage
morie_did_fuzzy(
data,
outcome,
assignment,
takeup,
post,
covariates = NULL,
cluster = NULL,
alpha = 0.05
)Arguments
- data
A data frame containing the outcome, treatment, post and any covariate columns.
- outcome
Name of the outcome column.
- assignment
Intent-to-treat assignment column.
- takeup
Actual treatment-takeup column.
- post
Name of the binary (0/1) post-period column.
- covariates
Optional character vector of covariate column names.
- cluster
Optional cluster ID column for CR1 standard errors.
- alpha
Significance level for confidence intervals (default 0.05).
Value
A result list; see morie_did_2x2.
Details
For the de Chaisemartin-D'Haultfoeuille fuzzy DiD estimator on
panel data prefer morie_did_chaisemartin_dhaultfoeuille
(DIDmultiplegt).