Skip to contents

Folds the real cepstrum to the causal half then re-exponentiates to produce a minimum-phase sequence with the same magnitude spectrum as x (approximate).

Usage

morie_dsp_min_phase(x)

Arguments

x

Numeric vector.

Value

Numeric vector, length(x).

References

Rangayyan & Krishnan (2015), Ch. 5; Oppenheim & Schafer (2010).