Folds the real cepstrum to the causal half then re-exponentiates
to produce a minimum-phase sequence with the same magnitude
spectrum as x (approximate).
Folds the real cepstrum to the causal half then re-exponentiates
to produce a minimum-phase sequence with the same magnitude
spectrum as x (approximate).