Kleibergen-Paap rank statistic
Arguments
- data
A
data.frame(or tibble) holding the outcome, endogenous regressors, instruments, and any exogenous controls.- endogenous
Character vector; column names of the endogenous regressors.
- instruments
Character vector; column names of the instrumental variables.
- exogenous
Optional character vector of additional exogenous regressors included in both the structural equation and the first stage.
NULL(default) for a just-identified design.