Skip to contents

Stock-Yogo critical values

Usage

morie_iv_stock_yogo(n_endogenous = 1, n_instruments = 1)

Arguments

n_endogenous

Integer; number of endogenous regressors used to look up the Stock-Yogo critical-value table.

n_instruments

Integer; number of instruments used to look up the Stock-Yogo critical-value table.