Skip to contents

Thin extender over kernlab::kpca that performs PCA in a feature space induced by a reproducing-kernel.

Usage

morie_kernel_pca(x, ...)

Arguments

x

Numeric matrix or data frame of features (rows = observations).

...

Further arguments forwarded to kernlab::kpca (e.g. kernel, kpar, features, th).

Value

A list with $method = "kernlab::kpca" and $raw (a kpca S4 object with eigenvalues, eigenvectors and the projected rotated data).

Examples

if (FALSE) { # \dontrun{
  if (requireNamespace("kernlab", quietly = TRUE)) {
    set.seed(1)
    x <- matrix(stats::rnorm(200), ncol = 4)
    morie_kernel_pca(x, kernel = "rbfdot", features = 2)
  }
} # }