Compares balance before and after matching and reports percent bias reduction, count of balanced covariates, and overlap statistics.
Value
A list with balance_before, balance_after,
bias_reduction, mean_bias_reduction,
pct_balanced_before, pct_balanced_after,
n_obs_before, n_obs_after.
Examples
if (FALSE) { # \dontrun{
morie_matching_quality(df, res$matched_data, "d", c("x1", "x2"))
} # }