Skip to contents

Computes bounds on the p-value for the treatment effect over a grid of values of gamma (the maximum odds ratio of differential treatment assignment due to an unobserved confounder). Uses the Wilcoxon signed-rank approach. For exact bounds, see sensitivitymv::senmv or the rbounds package.

Usage

morie_matching_rosenbaum_bounds(
  data,
  outcome,
  treatment,
  match_pairs,
  gamma_range = NULL
)

Arguments

data

Data frame.

outcome, treatment

Column names.

match_pairs

Data frame of matched indices.

gamma_range

Optional numeric vector of \(\Gamma\) values.

Value

A data frame with columns gamma, p_lower, p_upper, significant_lower, significant_upper.

References

Rosenbaum, P. R. (2002). Observational Studies (2nd ed.). Springer.

Examples

if (FALSE) { # \dontrun{
morie_matching_rosenbaum_bounds(df, "y", "d", res$match_pairs)
} # }