Skip to contents

Thin extender over performance::check_outliers for composite outlier detection on a fitted model or numeric data.

Usage

morie_performance_check_outliers(x, ...)

Arguments

x

A fitted model object or numeric data frame supported by performance::check_outliers.

...

Further arguments forwarded to performance::check_outliers (e.g. method, threshold).

Value

A list with $method = "performance::check_outliers" and $raw (the upstream outlier-check object).