Thin extender over performance::check_outliers for
composite outlier detection on a fitted model or numeric data.
Arguments
- x
A fitted model object or numeric data frame supported by
performance::check_outliers.- ...
Further arguments forwarded to
performance::check_outliers(e.g.method,threshold).