Skip to contents

Vectorised kernel functions on the support |u| <= 1 (Gaussian is on the real line). Used by RDD local-linear estimators and friends for kernel weighting around the cutoff.

Usage

morie_rdd_kernel_triangular(u)

morie_rdd_kernel_epanechnikov(u)

morie_rdd_kernel_uniform(u)

morie_rdd_kernel_gaussian(u)

Arguments

u

Numeric vector of standardised distances from the cutoff (i.e. \((x - c)/h\)).

Value

Numeric vector of kernel weights, same length as u.

Details

  • morie_rdd_kernel_triangular: \(K(u) = \max(1 - |u|, 0)\)

  • morie_rdd_kernel_epanechnikov: \(K(u) = (3/4)(1 - u^2)\) on |u| <= 1

  • morie_rdd_kernel_uniform: \(K(u) = 1/2\) on |u| <= 1

  • morie_rdd_kernel_gaussian: \(K(u) = \phi(u)\), the standard normal density