Tests a numeric series for randomness by dichotomizing around a
threshold and counting runs, with the exact normal approximation.
Reproduces randtests::runs.test.
Usage
morie_runs_test(x, threshold = stats::median(x), alternative = "two.sided")Tests a numeric series for randomness by dichotomizing around a
threshold and counting runs, with the exact normal approximation.
Reproduces randtests::runs.test.
morie_runs_test(x, threshold = stats::median(x), alternative = "two.sided")