Tipping-point sensitivity to a single unmeasured confounder (tipr)
Source:R/sensitivity.R
morie_sensitivity_tipping_point.RdThin interface to tipr::tip: returns the minimum value of
the standardised mean difference (smd) or partial R-squared
(R2) of an unmeasured confounder that would tip the lower
(or upper) bound of the confidence interval back to the null.
Pairs with tipping_point_analysis, which targets
missing-data sensitivity rather than unmeasured-confounder
sensitivity.
Arguments
- estimate
Observed treatment effect on the coefficient scale.
- smd
Hypothesised standardised mean difference of the unmeasured confounder between treatment groups.
- r2
Hypothesised partial R-squared of the unmeasured confounder with the outcome. Forwarded as the
r_squaredtipr argument.- ...
Additional arguments forwarded to
tipr::tip(e.g.outcome_type,confidence).
Value
A list of class morie_sensitivity_tipping_point
with the tipped point estimate and the raw tipr object.
References
D'Agostino McGowan, L. (2022). tipr: An R package for sensitivity analyses for unmeasured confounders. Journal of Open Source Software, 7(77), 4495.
Examples
if (requireNamespace("tipr", quietly = TRUE)) {
str(morie_sensitivity_tipping_point(0.5, smd = 0.3), max.level = 1)
}
#> ℹ The observed effect (0.5) WOULD be tipped by 1 unmeasured confounder with the
#> following specifications:
#> • estimated difference in scaled means between the unmeasured confounder in the
#> exposed population and unexposed population: 0.3
#> • estimated relationship between the unmeasured confounder and the outcome: 0.1
#> List of 6
#> $ estimate : num 0.5
#> $ smd : num 0.3
#> $ r2 : NULL
#> $ tipped_estimate: num 1
#> $ method : chr "tip (tipr)"
#> $ raw : tibble [1 × 5] (S3: tbl_df/tbl/data.frame)
#> - attr(*, "class")= chr [1:2] "morie_sensitivity_tipping_point" "list"