Tipping-point sensitivity to a single unmeasured confounder (tipr)
Source:R/sensitivity.R
morie_sensitivity_tipping_point.RdThin interface to tipr::tip: returns the minimum value of
the standardised mean difference (smd) or partial R-squared
(R2) of an unmeasured confounder that would tip the lower
(or upper) bound of the confidence interval back to the null.
Pairs with tipping_point_analysis, which targets
missing-data sensitivity rather than unmeasured-confounder
sensitivity.
Arguments
- estimate
Observed treatment effect on the coefficient scale.
- smd
Hypothesised standardised mean difference of the unmeasured confounder between treatment groups.
- r2
Hypothesised partial R-squared of the unmeasured confounder with the outcome. Forwarded as the
r_squaredtipr argument.- ...
Additional arguments forwarded to
tipr::tip(e.g.outcome_type,confidence).