Dynamic IRT with random-walk priors (stub)
Source:R/spatial_voting.R
morie_spatial_voting_dynamic_irt.RdTime-series IRT where ideal points evolve via a random walk: \(\phi_{i,t} \sim N(\phi_{i,t-1}, \tau^2)\).
Usage
morie_spatial_voting_dynamic_irt(
votes,
time_periods,
n_samples = 500L,
burn_in = 100L,
seed = 42L
)References
Martin, A. D. and Quinn, K. M. (2002). "Dynamic Ideal Point Estimation via Markov Chain Monte Carlo for the U.S. Supreme Court, 1953-1999." Political Analysis, 10(2).
Examples
if (FALSE) morie_spatial_voting_dynamic_irt(matrix(0, 4, 4), 1:4) # \dontrun{}