Skip to contents

Ratio estimator of a population total using known X_pop.

Usage

morie_survey_ratio(y, x, weights, X_population_total)

Arguments

y

Numeric vector of outcome values aligned with the sample.

x

Numeric vector of auxiliary values aligned with y (used in ratio estimation).

weights

Numeric vector of design weights aligned with y.

X_population_total

Known population total for the auxiliary variable x (ratio estimator).