Skip to contents

Fits the OU parameters (theta, mu, sigma) on daily counts (same OLS-on-first-differences as morie_tps_langevin_simulate), then evolves an initial gaussian density centred on the last observation by an explicit advection-diffusion finite-difference scheme with reflective boundaries on a grid spanning from 0 to 1.5 * max(counts) + 1.

Usage

morie_tps_fokker_planck_grid(df, ds_name = "?", n_grid = 64L, n_steps = 200L)

Arguments

df

A data.frame.

ds_name

Character label.

n_grid

Grid points (default 64).

n_steps

Time steps (default 200, each of length 0.05 days).

Value

A morie_rich_result list with theta, mu, sigma, grid, density, stationary_peak.