Returns autocorrelations indexed by lag in strict ascending order, so the lag index and the values always share the same ordering as the underlying series.
Usage
morie_ts_acf(x, lag_max = 20L, type = c("correlation", "covariance"))Returns autocorrelations indexed by lag in strict ascending order, so the lag index and the values always share the same ordering as the underlying series.
morie_ts_acf(x, lag_max = 20L, type = c("correlation", "covariance"))