Skip to contents

Thin wrapper over rbounds::psens() when rbounds is installed (rank-matched-pair signed-rank bounds across a Gamma grid). Without rbounds, falls back to a base R normal- approximation Wilcoxon signed-rank computation.

Usage

sensitivity_rosenbaum(
  data,
  treatment,
  outcome,
  covariates,
  gamma_range = c(1, 3),
  n_gamma = 20L
)

Arguments

data

Data frame with treatment + outcome columns.

treatment

Binary treatment column (0/1).

outcome

Outcome column.

covariates

Covariates (used only for matching approximation, here a simple rank-match).

gamma_range

c(min, max) of Gamma. Default c(1, 3).

n_gamma

Number of Gamma values. Default 20.

Value

Data frame with Gamma, p_lower, p_upper.