Tipping-point analysis for missing-data sensitivity
Source:R/sensitivity.R
tipping_point_analysis.RdHow much would unobserved outcomes need to differ from observed
ones for the treatment effect to become non-significant?
Phase 1.g cross-references tipr for the unmeasured-confounder
family of tipping-point calculations
(see also morie_sensitivity_tipping_point).
Usage
tipping_point_analysis(
estimate,
se,
n_treated,
n_control,
delta_range = NULL,
outcome_type = "continuous"
)Examples
str(tipping_point_analysis(0.5, 0.15, n_treated = 100, n_control = 100),
max.level = 1)
#> List of 6
#> $ delta_values : num [1:101] -1.5 -1.47 -1.44 -1.41 -1.38 -1.35 -1.32 -1.29 -1.26 -1.23 ...
#> $ adjusted_estimates: num [1:101] 2 1.97 1.94 1.91 1.88 1.85 1.82 1.79 1.76 1.73 ...
#> $ adjusted_p_values : num [1:101] 0 0 0 0 0 0 0 0 0 0 ...
#> $ tipping_point : num 0.18
#> $ original_estimate : num 0.5
#> $ interpretation : chr "The observed estimate (0.5000) becomes non-significant when outcomes for missing data differ by delta = 0.1800."| __truncated__
#> - attr(*, "class")= chr [1:2] "morie_tipping_point" "list"